@@ -1,5 +1,5 @@
 package Pod::Weaver::Section::SourceGitHub;
-our $VERSION = '0.51';
+$Pod::Weaver::Section::SourceGitHub::VERSION = '0.52';
 
 # ABSTRACT: Add SOURCE pod section for a github repository
 
@@ -15,8 +15,11 @@ sub weave_section {
 
     my $zilla = $input->{zilla} or return;
 
+    my $meta = eval { $zilla->distmeta }
+        or die "no distmeta data present";
+
     # pull repo out of distmeta resources.
-    my $repo = eval { $input->{zilla}{distmeta}{resources}{repository} }
+    my $repo = $meta->{resources}{repository}
         or die "repository not present in distmeta";
 
     return unless $repo =~ /github\.com/;
@@ -66,7 +69,7 @@ Pod::Weaver::Section::SourceGitHub - Add SOURCE pod section for a github reposit
 
 =head1 VERSION
 
-version 0.51
+version 0.52
 
 =head1 SYNOPSIS
 
